/**
 * Asserts at compile time that the provided type argument's type resolves to the expected boolean literal type.
 * @param expectTrue - True if the passed in type argument resolved to true.
 */
export declare function assert<T extends true | false>(expectTrue: T): void;
/**
 * Asserts at compile time that the provided type argument's type resolves to true.
 */
export declare type AssertTrue<T extends true> = never;
/**
 * Asserts at compile time that the provided type argument's type resolves to false.
 */
export declare type AssertFalse<T extends false> = never;
/**
 * Asserts at compile time that the provided type argument's type resolves to the expected boolean literal type.
 */
export declare type Assert<T extends true | false, Expected extends T> = never;
/**
 * Checks if the type `T` has the specified type `U`.
 */
export declare type Has<T, U> = IsAny<T> extends true ? true : IsAny<U> extends true ? false : Extract<T, U> extends never ? false : true;
/** @deprecated Use `Has<T, U>` */
export declare type HasType<T, U> = Has<T, U>;
/**
 * Checks if the type `T` does not have the specified type `U`.
 */
export declare type NotHas<T, U> = Has<T, U> extends true ? false : true;
/** @deprecated Use `NotHas<T, U>` */
export declare type NotHasType<T, U> = NotHas<T, U>;
/**
 * Checks if the type `T` is possibly null or undefined.
 */
export declare type IsNullable<T> = Extract<T, null | undefined> extends never ? false : true;
/** @deprecated Use `IsNullable<T>` */
export declare type IsNullableType<T> = IsNullable<T>;
/**
 * Checks if the type `T` exactly matches type `U`.
 * @remarks This is useful for checking if two union types match exactly.
 */
export declare type IsExact<T, U> = IsAny<T> extends true ? IsAny<U> extends true ? true : false : IsAny<U> extends true ? false : [T] extends [U] ? [U] extends [T] ? true : false : false;
/** @deprecated Use `IsExactType<T, U>` */
export declare type IsExactType<T, U> = IsExact<T, U>;
/**
 * Checks if the type `T` is the `any` type.
 */
export declare type IsAny<T> = IsUnknown<T> extends true ? false : IsNever<T> extends true ? false : T extends any ? any extends T ? true : false : false;
/**
 * Checks it the type `T` is the `never` type.
 */
export declare type IsNever<T> = [T] extends [never] ? true : false;
/** @deprecated Use `IsNever<T>` */
export declare type IsNeverType<T> = IsNever<T>;
/**
 * Checks it the type `T` is the `unknown` type.
 */
export declare type IsUnknown<T> = IsNever<T> extends true ? false : (T extends unknown ? unknown extends T ? T extends string ? false : true : false : false);
